@@ -1,5 +1,6 @@
 """str SQL utilities."""
 import functools
+import textwrap
 from typing import Dict, List, Optional
 
 from wpdatautil.textwrap import indent4
@@ -8,20 +9,21 @@ from wpdatautil.textwrap import indent4
 class SqlQuery:
     """SQL query helper to apply transformations to input columns, returning the output columns and query."""
 
-    def __init__(self, inputs: List[str], *, transformations: Dict[str, Optional[str]], template: str) -> None:
+    def __init__(self, inputs: List[str], *, transformations: Dict[str, Optional[str]], template: str, indent: int = 0) -> None:
         """Return a SQL query object.
 
         :param inputs: Input column names.
         :param transformations: Applicable transformations to input columns. If a column is to be transformed, its name is the key and its value is the transformation.
                                 In the value, {col} is replaced with the respective column name. If the value is None, the column is skipped.
         :param template: SQL query to format. In it, {selections} is formatted with the actual selections.
+        :param indent: The output query is indented by this number of spaces.
 
         Example: SqlQuery(['c1', 'c2', 'c3'],
                   transformations={'c2': None, 'c3': '{col} * 2', 'c4': 'count(*)'},
                   template="SELECT {selections}
                             FROM t")
         """
-        self._inputs, self._transformations, self._template = inputs, transformations, template
+        self._inputs, self._transformations, self._template, self._indent = inputs, transformations, template, indent
 
     @functools.cached_property
     def selections(self) -> Dict[str, str]:
@@ -52,7 +54,9 @@ class SqlQuery:
             FROM t
 
         """
-        return self._template.format(selections=sql_column_selections_str(self.selections))
+        query = self._template.format(selections=sql_column_selections_str(self.selections))
+        query = textwrap.indent(query, prefix=" " * self._indent)
+        return query
 
 
 def sql_column_selections(inputs: List[str], *, transformations: Dict[str, Optional[str]]) -> Dict[str, str]:
